A Python ChromeDriver wrapper that takes full page screenshots.
ChromeScreenshot
================

.. pypi-buttons
.. ci-buttons

TODO
====

- Write deterministic tests

- CI jobs. Travis?
  - enfore PR pass tests

- Produce documentation

- pypi package

- badges

Installation
============

TODO

Documentation
=============

TODO

Contributing
============

TODO

License
=======
::

  Copyright 2016 Grant Welch

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.


